pub struct InMemoryIntrospectionCache { /* private fields */ }Implementations
Sourceimpl InMemoryIntrospectionCache
impl InMemoryIntrospectionCache
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new in memory cache, with setting a default max_capacity of 10_000 entries.
and a TTL expiry of 15 minutes, which is much smaller than the default access token lifetime
in Zitadel.
A small cache expiry is desired to detect revoked tokens and changes in role assignments
outside the token lifetime.
For more fine-grained control use [new_from_cache].
Sourcepub fn new_from_cache(
cache: Cache<String, (ZitadelIntrospectionResponse, i64)>,
) -> Self
pub fn new_from_cache( cache: Cache<String, (ZitadelIntrospectionResponse, i64)>, ) -> Self
Create a new in memory cache from a preconfigured Moka cache. Use the re-exposed CacheBuilder to set custom configuration values.
use std::time::Duration;
use zitadel::oidc::introspection::cache::in_memory::InMemoryIntrospectionCache;
use zitadel::oidc::introspection::cache::in_memory::CacheBuilder;
let cache = InMemoryIntrospectionCache::new_from_cache(
CacheBuilder::new(10_000)
// use short lifetime to make sure token invalidation can be detected
.time_to_live(Duration::from_secs(60*15))
.build()
);Trait Implementations
Sourceimpl Debug for InMemoryIntrospectionCache
impl Debug for InMemoryIntrospectionCache
Sourceimpl Default for InMemoryIntrospectionCache
impl Default for InMemoryIntrospectionCache
Sourceimpl IntrospectionCache for InMemoryIntrospectionCache
impl IntrospectionCache for InMemoryIntrospectionCache
Sourcefn get<'life0, 'life1, 'async_trait>(
&'life0 self,
token: &'life1 str,
) -> Pin<Box<dyn Future<Output = Option<ZitadelIntrospectionResponse>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get<'life0, 'life1, 'async_trait>(
&'life0 self,
token: &'life1 str,
) -> Pin<Box<dyn Future<Output = Option<ZitadelIntrospectionResponse>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Sourcefn set<'life0, 'life1, 'async_trait>(
&'life0 self,
token: &'life1 str,
response: ZitadelIntrospectionResponse,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn set<'life0, 'life1, 'async_trait>(
&'life0 self,
token: &'life1 str,
response: ZitadelIntrospectionResponse,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,